@@ -56,17 +56,12 @@ func (*User) GetInterfaceName() string {
 func (u *User) SetFullName(sender dbus.Sender, name string) *dbus.Error {
 	logger.Debugf("[SetFullName] new name: %q", name)
 
-	err := u.checkAuth(sender, true, "")
+	err := u.checkAuth(sender, false, "")
 	if err != nil {
 		logger.Debug("[SetFullName] access denied:", err)
 		return dbusutil.ToError(err)
 	}
 
-	if !u.checkIsControlCenter(sender) {
-		logger.Debug("[SetLocale] access denied: only dde-control-center allowed")
-		return dbusutil.ToError(fmt.Errorf("only dde-control-center allowed to call this method"))
-	}
-
 	u.PropsMu.Lock()
 	defer u.PropsMu.Unlock()
 
@@ -389,11 +384,6 @@ func (u *User) SetLocale(sender dbus.Sender, locale string) *dbus.Error {
 		return dbusutil.ToError(err)
 	}
 
-	if !u.checkIsDeepinDaemon(sender) {
-		logger.Debug("[SetLocale] access denied: only deepin daemons allowed")
-		return dbusutil.ToError(fmt.Errorf("only deepin daemons allowed to call this method"))
-	}
-
 	if !lang_info.IsSupportedLocale(locale) {
 		err := fmt.Errorf("invalid locale %q", locale)
 		logger.Debug("[SetLocale]", err)
@@ -425,8 +415,6 @@ func (u *User) SetLayout(sender dbus.Sender, layout string) *dbus.Error {
 		return dbusutil.ToError(err)
 	}
 
-	// TODO: check layout validity
-
 	u.PropsMu.Lock()
 	defer u.PropsMu.Unlock()
 
@@ -610,8 +598,10 @@ func (u *User) DeleteIconFile(sender dbus.Sender, icon string) *dbus.Error {
 func (u *User) EnableWechatAuth(sender dbus.Sender, value bool) *dbus.Error {
 	logger.Infof("DBus call EnableWechatAuth sender %v, enabled %t", sender, value)
 	// 验证调用者权限
-	if !u.checkIsControlCenter(sender) {
-		return dbusutil.ToError(fmt.Errorf("not allow %v call this method", sender))
+	err := u.checkAuth(sender, true, "")
+	if err != nil {
+		logger.Debug("[EnableWechatAuth] access denied:", err)
+		return dbusutil.ToError(err)
 	}
 	return u.enableWechatAuth(value)
 }
