@@ -14,7 +14,6 @@ import (
 	"github.com/godbus/dbus/v5"
 	"github.com/linuxdeepin/go-lib/dbusutil"
 	"github.com/linuxdeepin/go-lib/keyfile"
-	"github.com/linuxdeepin/go-lib/procfs"
 )
 
 //go:generate dbusutil-gen em -type Manager
@@ -58,21 +57,8 @@ type Manager struct {
 }
 
 func (m *Manager) UpdateGreeterQtTheme(sender dbus.Sender, fd dbus.UnixFD) *dbus.Error {
-	pid, err := m.service.GetConnPID(string(sender))
-	if err != nil {
-		logger.Warning(err)
-	} else {
-		p := procfs.Process(pid)
-		cmd, err := p.Exe()
-		if err != nil {
-			logger.Warning(err)
-		} else {
-			logger.Info("Calling UpdateGreeterQtTheme by ", cmd)
-		}
-	}
-
 	m.service.DelayAutoQuit()
-	err = updateGreeterQtTheme(fd)
+	err := updateGreeterQtTheme(fd)
 	if err != nil {
 		logger.Warning(err)
 	}
@@ -83,10 +69,8 @@ func (m *Manager) UpdateGreeterQtTheme(sender dbus.Sender, fd dbus.UnixFD) *dbus
 func updateGreeterQtTheme(fd dbus.UnixFD) error {
 	f := os.NewFile(uintptr(fd), "")
 	defer f.Close()
-	err := os.MkdirAll("/etc/lightdm/deepin", 0755)
-	if err != nil {
-		return err
-	}
+
+	// 目录创建由 postinst 脚本处理，这里只负责文件写入
 	const themeFileTemp = themeFile + ".tmp"
 	dest, err := os.Create(themeFileTemp)
 	if err != nil {
@@ -120,6 +104,7 @@ func updateXSettingsConfig() {
 		return
 	}
 
+	// 目录创建由 postinst 脚本处理，这里只负责文件写入
 	xf, err := os.OpenFile(xsettingsFile, os.O_WRONLY|os.O_CREATE|os.O_TRUNC, 0644)
 	if err != nil {
 		logger.Warning(err)
