@@ -184,12 +184,10 @@ func (s *SessionDaemon) initModules() {
 	}
 
 	part2ModuleNames := []string{
-		"network",
 		"audio",
 		"screensaver",
 		"sessionwatcher",
 		"power", // need screensaver and sessionwatcher
-		"uadpagent",
 		"service-trigger",
 		"clipboard",
 		"keybinding",
