@@ -5,25 +5,28 @@
 package main
 
 import (
-	"github.com/godbus/dbus/v5"
-	login1 "github.com/linuxdeepin/go-dbus-factory/system/org.freedesktop.login1"
 	"github.com/linuxdeepin/go-lib/dbusutil"
+	"os/exec"
 )
 
-func (d *Daemon) forwardPrepareForSleepSignal(service *dbusutil.Service) error {
-	systemBus, err := dbus.SystemBus()
+// TODO: 临时方案，hwe一些机型内核wifi有问题，需要停止wifip2p扫描，待内核修改后去掉
+func stopNetworkDisaplay() {
+	err := exec.Command("killall", "deepin-network-display-daemon").Run()
 	if err != nil {
-		return err
+		logger.Warning("Failed to stop network disaplay")
 	}
-	d.loginManager = login1.NewManager(systemBus)
-	d.systemSigLoop = dbusutil.NewSignalLoop(systemBus, 10)
-	d.systemSigLoop.Start()
+}
+
+func (d *Daemon) forwardPrepareForSleepSignal(service *dbusutil.Service) error {
 	d.loginManager.InitSignalExt(d.systemSigLoop, true)
 
-	_, err = d.loginManager.ConnectPrepareForSleep(func(before bool) {
+	_, err := d.loginManager.ConnectPrepareForSleep(func(before bool) {
 		logger.Info("login1 PrepareForSleep", before)
 		// signal `PrepareForSleep` true -> false
-		err = service.Emit(d, "HandleForSleep", before)
+		if before {
+			stopNetworkDisaplay()
+		}
+		err := service.Emit(d, "HandleForSleep", before)
 		if err != nil {
 			logger.Warning("failed to emit HandleForSleep signal")
 			return
