@@ -24,16 +24,14 @@ import (
 
 type mouseInfo struct {
 	*dxinput.Mouse
-	devNode   string
-	sysfsPath string
-	phys      string
+	devNode string
+	phys    string
 }
 
 type touchpadInfo struct {
 	*dxinput.Touchpad
-	devNode   string
-	sysfsPath string
-	phys      string
+	devNode string
+	phys    string
 }
 
 type Mouses []*mouseInfo
@@ -106,7 +104,7 @@ func getKeyboardNumber() int {
 	return number
 }
 
-func getExtraInfo(id int32) (devNode string, sysfsPath string, phys string) {
+func getExtraInfo(id int32) (devNode string, phys string) {
 	var devNodeBytes []byte
 	var length int32
 	sessionType := os.Getenv("XDG_SESSION_TYPE")
@@ -127,7 +125,6 @@ func getExtraInfo(id int32) (devNode string, sysfsPath string, phys string) {
 		return
 	}
 	defer udevDev.Unref()
-	sysfsPath = udevDev.GetSysfsPath()
 	phys = udevDev.GetSysfsAttr("phys")
 	if phys == "" {
 		parent := udevDev.GetParent()
@@ -148,7 +145,7 @@ func getTouchpadInfoByDxTouchpad(tmp *dxinput.Touchpad) *touchpadInfo {
 		Touchpad: tmp,
 	}
 
-	m.devNode, m.sysfsPath, m.phys = getExtraInfo(tmp.Id)
+	m.devNode, m.phys = getExtraInfo(tmp.Id)
 
 	return m
 }
@@ -158,7 +155,7 @@ func getMouseInfoByDxMouse(tmp *dxinput.Mouse) *mouseInfo {
 		Mouse: tmp,
 	}
 
-	m.devNode, m.sysfsPath, m.phys = getExtraInfo(tmp.Id)
+	m.devNode, m.phys = getExtraInfo(tmp.Id)
 
 	return m
 }
@@ -173,10 +170,6 @@ func getMouseInfos(force bool) Mouses {
 		if info.Type == common.DevTypeMouse {
 			tmp, _ := dxinput.NewMouseFromDeviceInfo(info)
 			mouse := getMouseInfoByDxMouse(tmp)
-			if mouse.isVirtual() {
-				logger.Debug("ignore virtial mouse:", tmp.Name)
-				continue
-			}
 
 			// phys 用来标识物理设备，若俩设备的 phys 相同，说明是同一物理设备，
 			// 若 phys 与某个触摸板的 phys 相同，说明是同一个设备（触摸板），忽略此鼠标设备
@@ -224,23 +217,13 @@ func getTPadInfos(force, check bool) Touchpads {
 				logger.Warning(err)
 			} else {
 				touchpad := getTouchpadInfoByDxTouchpad(tmp)
-				if touchpad.isVirtual() {
-					logger.Debug("ignore virtial mouse:", tmp.Name)
-					continue
-				}
 				_tpadInfos = append(_tpadInfos, touchpad)
 			}
 			continue
 		}
 		if info.Type == common.DevTypeTouchpad {
 			tmp, _ := dxinput.NewTouchpadFromDevInfo(info)
-			touchpad := getTouchpadInfoByDxTouchpad(tmp)
-
-			if touchpad.isVirtual() {
-				logger.Debug("ignore virtial mouse:", tmp.Name)
-				continue
-			}
-			_tpadInfos = append(_tpadInfos, touchpad)
+			_tpadInfos = append(_tpadInfos, getTouchpadInfoByDxTouchpad(tmp))
 		}
 	}
 
@@ -307,14 +290,6 @@ func toJSON(v interface{}) string {
 	return string(data)
 }
 
-func (info mouseInfo) isVirtual() bool {
-	return strings.Contains(info.sysfsPath, "virtual")
-}
-
-func (info touchpadInfo) isVirtual() bool {
-	return strings.Contains(info.sysfsPath, "virtual")
-}
-
 func getKeyboardInfos(force bool) Keyboards {
 	if !force && len(_keyboardnfos) != 0 {
 		return _keyboardnfos
