@@ -14,7 +14,6 @@ import (
 	dbus "github.com/godbus/dbus/v5"
 	"github.com/linuxdeepin/dde-api/soundutils"
 	. "github.com/linuxdeepin/go-lib/gettext"
-	"github.com/linuxdeepin/go-lib/gsettings"
 	"github.com/linuxdeepin/go-lib/pulse"
 	"github.com/linuxdeepin/go-x11-client/ext/dpms"
 )
@@ -104,7 +103,7 @@ func (m *Manager) setDDEBlackScreenActive(active bool) {
 		return
 	}
 
-	if !m.SleepLock.Get() {
+	if !m.SleepLock {
 		logger.Info("setDDEBlackScreenActive GSettings of sleep-lock is false, Not use dde black widget")
 		return
 	}
@@ -294,6 +293,7 @@ func (m *Manager) doSuspend() {
 	}
 
 	logger.Debug("suspend")
+	m.captureScreensaverStateIfNeeded()
 	err := m.helper.SessionManager.RequestSuspend(0)
 	if err != nil {
 		logger.Warning("failed to suspend:", err)
@@ -308,6 +308,7 @@ func (m *Manager) doSuspendByFront() {
 	}
 
 	logger.Debug("suspend")
+	m.captureScreensaverStateIfNeeded()
 	err := m.helper.ShutdownFront.Suspend(0)
 	if err != nil {
 		logger.Warning("failed to suspend:", err)
@@ -437,7 +438,7 @@ func (m *Manager) doHibernateByFront() {
 }
 
 func (m *Manager) doTurnOffScreen() {
-	if m.ScreenBlackLock.Get() {
+	if m.ScreenBlackLock {
 		logger.Info("Show lock")
 		m.doLock(true)
 		time.Sleep(1 * time.Second)
@@ -494,7 +495,7 @@ func doCloseDDELowPower() {
 }
 
 func (m *Manager) sendNotify(icon, summary, body string) {
-	if !m.LowPowerNotifyEnable.Get() {
+	if !m.LowPowerNotifyEnable {
 		logger.Info("notify switch is off ")
 		return
 	}
@@ -531,6 +532,40 @@ const (
 	deepinScreensaverDBusInterface   = deepinScreensaverDBusServiceName
 )
 
+// 通用的屏幕保护属性获取方法
+func (m *Manager) getScreensaverProperty(propertyName string) bool {
+	bus, err := dbus.SessionBus()
+	if err != nil {
+		logger.Warning("failed to get session bus:", err)
+		return false
+	}
+
+	obj := bus.Object(deepinScreensaverDBusServiceName, deepinScreensaverDBusPath)
+	var variant dbus.Variant
+	err = obj.Call("org.freedesktop.DBus.Properties.Get", 0, deepinScreensaverDBusInterface, propertyName).Store(&variant)
+	if err != nil {
+		logger.Warning("failed to get screensaver "+propertyName+":", err)
+		return false
+	}
+
+	if variant.Signature().String() != "b" {
+		logger.Warning("screensaver " + propertyName + " property is not boolean type")
+		return false
+	}
+
+	return variant.Value().(bool)
+}
+
+// 检查屏幕保护是否正在运行
+func (m *Manager) isScreensaverRunning() bool {
+	return m.getScreensaverProperty("isRunning")
+}
+
+// 检查屏幕保护恢复时是否需要密码
+func (m *Manager) isScreensaverLockAtAwake() bool {
+	return m.getScreensaverProperty("lockScreenAtAwake")
+}
+
 func startScreensaver() {
 	logger.Info("start screensaver")
 	bus, err := dbus.SessionBus()
@@ -585,41 +620,44 @@ func suspendPulseSources(suspend int) {
 	}
 }
 
-func (m *Manager) initGSettingsConnectChanged() {
-	const powerSettingsIcon = "preferences-system"
-
+func (m *Manager) initDConfigConnectChanged() {
 	isIllegalAction := func(action int32) bool {
 		return (action == powerActionHibernate && !m.canHibernate()) ||
 			(action == powerActionSuspend && !m.canSuspend())
 	}
 
 	// 监听 session power 的属性的改变,并发送通知
-	gsettings.ConnectChanged(gsSchemaPower, "*", func(key string) {
+	m.dsPowerConfigManager.ConnectValueChanged(func(key string) {
 		logger.Debug("Power Settings Changed :", key)
 		switch key {
-		case settingKeyLinePowerLidClosedAction:
-			value := m.LinePowerLidClosedAction.Get()
+		case dsettingLinePowerLidClosedAction:
+			value := m.LinePowerLidClosedAction
 			if isIllegalAction(value) {
 				break
 			}
-		case settingKeyLinePowerPressPowerBtnAction:
-			value := m.LinePowerPressPowerBtnAction.Get()
+		case dsettingLinePowerPressPowerButton:
+			value := m.LinePowerPressPowerBtnAction
 			if isIllegalAction(value) {
 				break
 			}
-		case settingKeyBatteryLidClosedAction:
-			value := m.BatteryLidClosedAction.Get()
+		case dsettingBatteryLidClosedAction:
+			value := m.BatteryLidClosedAction
 			if isIllegalAction(value) {
 				break
 			}
-		case settingKeyBatteryPressPowerBtnAction:
-			value := m.BatteryPressPowerBtnAction.Get()
+		case dsettingBatteryPressPowerButton:
+			value := m.BatteryPressPowerBtnAction
 			if isIllegalAction(value) {
 				break
 			}
-		case settingKeyHighPerformanceEnabled:
+		case dsettingHighPerformanceEnabled:
 			// 根据systemPower::IsHighPerformanceEnabled GSetting::settingKeyHighPerformanceEnabled
-			bSettingKeyHighPerformanceEnabled := m.settings.GetBoolean(settingKeyHighPerformanceEnabled)
+			highPerformanceEnabled, err := m.dsPowerConfigManager.Value(0, dsettingHighPerformanceEnabled)
+			if err != nil {
+				logger.Warning(err)
+				return
+			}
+			bSettingKeyHighPerformanceEnabled := highPerformanceEnabled.Value().(bool)
 			if bSettingKeyHighPerformanceEnabled == m.gsHighPerformanceEnabled {
 				return
 			}
@@ -717,3 +755,14 @@ func byteSliceEqual(v1, v2 []byte) bool {
 	}
 	return true
 }
+
+func (m *Manager) captureScreensaverStateIfNeeded() {
+	if m == nil || m.screensaverStateCaptured {
+		return
+	}
+
+	// 仅捕获恢复是否需要密码；是否“正在运行”由停止屏保前的路径设置
+	m.screensaverLockAtAwake = m.isScreensaverLockAtAwake()
+	m.screensaverStateCaptured = true
+	logger.Debug("capture screensaver lockAtAwake=", m.screensaverLockAtAwake)
+}
