@@ -15,7 +15,7 @@ import (
 	dbus "github.com/godbus/dbus/v5"
 	"github.com/linuxdeepin/dde-api/powersupply"
 	"github.com/linuxdeepin/dde-api/powersupply/battery"
-	ConfigManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
+	"github.com/linuxdeepin/dde-daemon/common/dconfig"
 	DisplayManager "github.com/linuxdeepin/go-dbus-factory/system/org.freedesktop.DisplayManager"
 	gudev "github.com/linuxdeepin/go-gir/gudev-1.0"
 	"github.com/linuxdeepin/go-lib/dbusutil"
@@ -32,6 +32,8 @@ const (
 	dsettingsPowerSavingModeAutoBatteryPercent    = "powerSavingModeAutoBatteryPercent"
 	dsettingsPowerMappingConfig                   = "powerMappingConfig"
 	dsettingsMode                                 = "mode"
+	dsettingsSmartBatteryStatus                   = "smartBatteryStatus"
+	dsettingsSmartBatteryOnThreshold              = "smartBatteryOnThreshold"
 )
 
 type supportMode struct {
@@ -51,7 +53,7 @@ type Manager struct {
 	batteriesMu   sync.Mutex
 	ac            *AC
 	gudevClient   *gudev.Client
-	dsgPower      ConfigManager.Manager
+	dsgPower      *dconfig.DConfig
 	// 电池是否电量低
 	batteryLow bool
 	// 初始化是否完成
@@ -62,6 +64,7 @@ type Manager struct {
 	PropsMu      sync.RWMutex
 	OnBattery    bool
 	HasLidSwitch bool
+	LidClosed    bool
 	// battery display properties:
 	HasBattery         bool
 	BatteryPercentage  float64
@@ -89,6 +92,12 @@ type Manager struct {
 	// 开启节能模式时保存的数据
 	PowerSavingModeBrightnessData string `prop:"access:rw"`
 
+	// 是否开启"智能电量"
+	smartBatteryStatus bool
+
+	// 开启"智能电量"阀值
+	smartBatteryOnThreshold float64
+
 	// CPU频率调节模式，支持powersave和performance
 	CpuGovernor string
 
@@ -257,13 +266,14 @@ func (m *Manager) init() error {
 func (m *Manager) initDsgConfig() error {
 	logger.Info("org.deepin.dde.Power1 module start init dconfig.")
 	// dsg 配置
-	ds := ConfigManager.NewConfigManager(m.service.Conn())
+	// ds := ConfigManager.NewConfigManager(m.service.Conn())
 
-	dsPowerPath, err := ds.AcquireManager(0, dsettingsAppID, dsettingsPowerName, "")
-	if err != nil {
-		return err
-	}
-	dsPower, err := ConfigManager.NewManager(m.service.Conn(), dsPowerPath)
+	// dsPowerPath, err := ds.AcquireManager(0, dsettingsAppID, dsettingsPowerName, "")
+	// if err != nil {
+	// 	return err
+	// }
+	// dsPower, err := ConfigManager.NewManager(m.service.Conn(), dsPowerPath)
+	dsPower, err := dconfig.NewDConfig(dsettingsAppID, dsettingsPowerName, "")
 	if err != nil {
 		return err
 	}
@@ -285,125 +295,93 @@ func (m *Manager) initDsgConfig() error {
 	}
 
 	getPowerSavingModeAuto := func(init bool) {
-		data, err := dsPower.Value(0, dsettingsPowerSavingModeAuto)
+		data, err := dsPower.GetValueBool(dsettingsPowerSavingModeAuto)
 		if err != nil {
 			logger.Warning(err)
 			return
 		}
 
 		if init {
-			m.PowerSavingModeAuto = data.Value().(bool)
+			m.PowerSavingModeAuto = data
 			return
 		}
 
-		m.setPropPowerSavingModeAuto(data.Value().(bool))
+		m.setPropPowerSavingModeAuto(data)
 	}
 
 	getPowerSavingModeEnabled := func(init bool) {
-		data, err := dsPower.Value(0, dsettingsPowerSavingModeEnabled)
+		data, err := dsPower.GetValueBool(dsettingsPowerSavingModeEnabled)
 		if err != nil {
 			logger.Warning(err)
 			return
 		}
 
 		if init {
-			m.PowerSavingModeEnabled = data.Value().(bool)
+			m.PowerSavingModeEnabled = data
 			return
 		}
 
-		m.setPropPowerSavingModeEnabled(data.Value().(bool))
+		m.setPropPowerSavingModeEnabled(data)
 	}
 
 	getPowerSavingModeAutoWhenBatteryLow := func(init bool) {
-		data, err := dsPower.Value(0, dsettingsPowerSavingModeAutoWhenBatteryLow)
+		data, err := dsPower.GetValueBool(dsettingsPowerSavingModeAutoWhenBatteryLow)
 		if err != nil {
 			logger.Warning(err)
 			return
 		}
 
 		if init {
-			m.PowerSavingModeAutoWhenBatteryLow = data.Value().(bool)
+			m.PowerSavingModeAutoWhenBatteryLow = data
 			return
 		}
 
-		m.setPropPowerSavingModeAutoWhenBatteryLow(data.Value().(bool))
+		m.setPropPowerSavingModeAutoWhenBatteryLow(data)
 	}
 
 	getPowerSavingModeBrightnessDropPercent := func(init bool) {
-		data, err := dsPower.Value(0, dsettingsPowerSavingModeBrightnessDropPercent)
+		data, err := dsPower.GetValueInt64(dsettingsPowerSavingModeBrightnessDropPercent)
 		if err != nil {
 			logger.Warning(err)
 			return
 		}
 
 		if init {
-			switch vv := data.Value().(type) {
-			case float64:
-				m.PowerSavingModeBrightnessDropPercent = uint32(vv)
-			case int64:
-				m.PowerSavingModeBrightnessDropPercent = uint32(vv)
-			default:
-				logger.Warning("type is wrong! type : ", vv)
-			}
-
+			m.PowerSavingModeBrightnessDropPercent = uint32(data)
 			return
 		}
 
 		ret := false
-		switch vv := data.Value().(type) {
-		case float64:
-			ret = m.setPropPowerSavingModeBrightnessDropPercent(uint32(vv))
-		case int64:
-			ret = m.setPropPowerSavingModeBrightnessDropPercent(uint32(vv))
-		default:
-			logger.Warning("type is wrong! type : ", vv)
-		}
+		m.setPropPowerSavingModeBrightnessDropPercent(uint32(data))
 		if ret {
 			logger.Info("Set power saving mode brightness drop percent", m.PowerSavingModeBrightnessDropPercent)
 		}
 	}
 	getPowerSavingModeAutoBatteryPercent := func(init bool) {
-		data, err := dsPower.Value(0, dsettingsPowerSavingModeAutoBatteryPercent)
+		data, err := dsPower.GetValueInt64(dsettingsPowerSavingModeAutoBatteryPercent)
 		if err != nil {
 			logger.Warning(err)
 			return
 		}
 
 		if init {
-			switch vv := data.Value().(type) {
-			case float64:
-				m.PowerSavingModeAutoBatteryPercent = uint32(vv)
-			case int64:
-				m.PowerSavingModeAutoBatteryPercent = uint32(vv)
-			default:
-				logger.Warning("type is wrong! type : ", vv)
-			}
-
+			m.PowerSavingModeAutoBatteryPercent = uint32(data)
 			return
 		}
 
 		ret := false
-		switch vv := data.Value().(type) {
-		case float64:
-			ret = m.setPropPowerSavingModeAutoBatteryPercent(uint32(vv))
-		case int64:
-			ret = m.setPropPowerSavingModeAutoBatteryPercent(uint32(vv))
-		default:
-			logger.Warning("type is wrong! type : ", vv)
-		}
+		m.setPropPowerSavingModeAutoBatteryPercent(uint32(data))
 		if ret {
 			logger.Info("Set power saving mode auto battery percent", m.PowerSavingModeAutoBatteryPercent)
 		}
 	}
 
 	getMode := func(init bool) string {
-		ret, err := dsPower.Value(0, dsettingsMode)
+		value, err := dsPower.GetValueString(dsettingsMode)
 		if err != nil {
 			logger.Warning(err)
 			return ddeBalance
 		}
-
-		value := ret.Value().(string)
 		logger.Infof("value:%v", value)
 		// dsg更新配置后，校验mode有效性
 		if !_validPowerModeArray.Contains(value) {
@@ -420,13 +398,12 @@ func (m *Manager) initDsgConfig() error {
 	}
 
 	getPowerMappingConfig := func() {
-		data, err := dsPower.Value(0, dsettingsPowerMappingConfig)
+		configStr, err := dsPower.GetValueString(dsettingsPowerMappingConfig)
 		if err != nil {
 			logger.Warning(err)
 			return
 		}
 		config := make(map[string]powerConfig)
-		configStr := data.Value().(string)
 		err = json.Unmarshal([]byte(configStr), &config)
 		if err != nil {
 			logger.Warning(err)
@@ -441,6 +418,32 @@ func (m *Manager) initDsgConfig() error {
 		}
 	}
 
+	getSmartBatteryStatus := func() {
+		data, err := dsPower.GetValueBool(dsettingsSmartBatteryStatus)
+		if err != nil {
+			logger.Warning(err)
+			return
+		}
+
+		m.smartBatteryStatus = data
+		logger.Info("dsg of smartBatteryStatus : ", m.smartBatteryStatus)
+	}
+
+	getSmartBatteryOnThreshold := func() {
+		data, err := dsPower.GetValueFloat64(dsettingsSmartBatteryOnThreshold)
+		if err != nil {
+			logger.Warning(err)
+			return
+		}
+		m.smartBatteryOnThreshold = data
+		if m.smartBatteryOnThreshold < 85.0 {
+			m.smartBatteryOnThreshold = 85.0
+		} else if m.smartBatteryOnThreshold > 100.0 {
+			m.smartBatteryOnThreshold = 100.0
+		}
+		logger.Info("dsg of smartBatteryOnThreshold : ", m.smartBatteryOnThreshold)
+	}
+
 	getPowerSavingModeAuto(true)
 	getPowerSavingModeEnabled(true)
 	getPowerSavingModeAutoWhenBatteryLow(true)
@@ -448,9 +451,10 @@ func (m *Manager) initDsgConfig() error {
 	getPowerSavingModeAutoBatteryPercent(true)
 	getMode(true)
 	getPowerMappingConfig()
+	getSmartBatteryStatus()
+	getSmartBatteryOnThreshold()
 
-	dsPower.InitSignalExt(m.systemSigLoop, true)
-	_, _ = dsPower.ConnectValueChanged(func(key string) {
+	dsPower.ConnectValueChanged(func(key string) {
 		logger.Info("dconfig org.deepin.dde.daemon.power valueChanged, key : ", key)
 		switch key {
 		case dsettingsPowerSavingModeAuto:
@@ -479,6 +483,12 @@ func (m *Manager) initDsgConfig() error {
 			return
 		case dsettingsPowerMappingConfig:
 			getPowerMappingConfig()
+		case dsettingsSmartBatteryStatus:
+			getSmartBatteryStatus()
+			m.refreshSmartBattery()
+		case dsettingsSmartBatteryOnThreshold:
+			getSmartBatteryOnThreshold()
+			m.refreshSmartBattery()
 		default:
 			logger.Debug("Not process. valueChanged, key : ", key)
 		}
@@ -574,6 +584,7 @@ func (m *Manager) addBattery(dev *gudev.Device) (*Battery, bool) {
 	m.batteriesMu.Lock()
 	m.batteries[sysfsPath] = bat
 	m.refreshBatteryDisplay()
+	m.refreshSmartBattery()
 	m.batteriesMu.Unlock()
 	bat.setRefreshDoneCallback(m.refreshBatteryDisplay)
 	return bat, true
