@@ -7,8 +7,7 @@ package power
 import (
 	"errors"
 
-	"github.com/godbus/dbus/v5"
-	ConfigManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
+	"github.com/linuxdeepin/dde-daemon/common/dconfig"
 	"github.com/linuxdeepin/go-lib/utils"
 )
 
@@ -25,11 +24,11 @@ func interfaceToArrayString(v interface{}) (d []interface{}) {
 	return
 }
 
-func (m *Manager) setDsgData(key string, value interface{}, dsg ConfigManager.Manager) error {
+func (m *Manager) setDsgData(key string, value interface{}, dsg *dconfig.DConfig) error {
 	if dsg == nil {
 		return errors.New("setDsgData dsg is nil")
 	}
-	err := dsg.SetValue(0, key, dbus.MakeVariant(value))
+	err := dsg.SetValue(key, value)
 	if err != nil {
 		logger.Warningf("setDsgData key : %s. err : %v", key, err)
 		return err
